@echo off
REM cq2wmap.cmd -- compile a Quake2World map
REM usage: "cq2wmap <mapname> <quality>"
REM
REM * Place this file in your quake2world/ directory.
REM
REM * You obviously need q2wmap.exe for this to work, it comes with q2w and should already
REM   be in the same directory. 
REM
REM written by spirit - http://maps.sp1r1t.org

REM settings -- they should be fine the way they are if this script is at the correct place (see above)
@set COMPPATH=q2wmap.exe
@set MAPPATH=maps

REM more settings -- no need to mess with these, but you may.
@set APPTAG=[CQ2WMAP]
@set QUALITY1=-bsp -vis -light -extra
@set QUALITY2=-bsp -vis -light
@set QUALITY3=-bsp -vis
@set QUALITY4=-bsp -vis -fast
@set QUALITY5=-bsp

REM don't mess with these, they are constructed from the settings above
@set MAPFILE=%MAPPATH%\%1.map
@set BSPFILE=%MAPPATH%\%1.bsp

echo %APPTAG% === cq2wmap ===

REM check for args, bail out if missing
if {%1} == {} (goto :HELP)
if {%2} == {} (goto :HELP)


@set MAP=%1
echo %APPTAG% assuming map %MAP%, looking for map file at %MAPFILE%.
echo %APPTAG% writing bsp file to %BSPFILE%.
echo %APPTAG% DEBUG: arg1 was %1, arg2 was %2.

REM check quality and compile
if {%2} == {1} (goto :Q1)
if {%2} == {2} (goto :Q2)
if {%2} == {3} (goto :Q3)
if {%2} == {4} (goto :Q4)
if {%2} == {5} (goto :Q5)


REM comilation procedures
REM note that the first (Q1) will be assumed if no other is specified

:Q1
echo %APPTAG% compiling your map %MAP% at quality 1 (%QUALITY1%).
%COMPPATH% %QUALITY1% %MAPFILE%
echo %APPTAG% done at quality 1 (%QUALITY1%).
goto :DONE

:Q2
echo %APPTAG% compiling your map %MAP% at quality 2 (%QUALITY2%).
%COMPPATH% %QUALITY2% %MAPFILE%
echo %APPTAG% done at quality 2 (%QUALITY2%).
goto :DONE

:Q3
echo %APPTAG% compiling your map %MAP% at quality 3 (%QUALITY3%).
%COMPPATH% %QUALITY3% %MAPFILE%
echo %APPTAG% done at quality 3 (%QUALITY3%).
goto :DONE

:Q4
echo %APPTAG% compiling your map %MAP% at quality 4 (%QUALITY4%).
%COMPPATH% %QUALITY4% %MAPFILE%
echo %APPTAG% done at quality 4 (%QUALITY4%).
goto :DONE

:Q5
echo %APPTAG% compiling your map %MAP% at quality 5 (%QUALITY5%).
%COMPPATH% %QUALITY5% %MAPFILE%
echo %APPTAG% done at quality 5 (%QUALITY5%).
goto :DONE

REM other functions
:HELP
echo %APPTAG% USAGE:
echo %APPTAG% cq2wmap mapname quality
echo %APPTAG% mapname: name of your mapfile, no extension
echo %APPTAG% quality: quality, 1 is best but slowest, 5 fastest but ugliest
echo %APPTAG% example: cq2wmap mymap 2
goto :EOF


:DONE
REM we're done: bye bye, baby, bye bye. but don't forget the materials!
%COMPPATH% -mat %MAPFILE%
echo %APPTAG% Compiled map %MAP%, bsp file should be at %BSPFILE% if everything was ok.
echo %APPTAG% Check the output above for errors to be sure.
echo %APPTAG% Exiting.
goto :EOF

:ERR
echo %APPTAG% Error, Exiting.
goto :EOF

:EOF


